caellion-python-commons: tests.test_stringutil_formatters.TestStringUtilFormatters Class Reference

caellion-python-commons

Public Member Functions | List of all members
tests.test_stringutil_formatters.TestStringUtilFormatters Class Reference

## Public Member Functions
def | test_fmt_si_plus (self, value, decimals, expected)
def | test_fmt_si_plus_no_decimals (self, value, expected)
def | test_fmt_si_minus (self, value, decimals, expected)
def | test_fmt_si_bin_plus (self, value, decimals, expected)
def | test_fmt_si_bin_plus_no_decimals (self, value, expected)
def | test_fmt_si_bin_minus (self, value, decimals, expected)
def | test_fmt_si_sub_plus (self, value, decimals, expected)
def | test_fmt_si_sub_plus_no_decimals (self, value, expected)
def | test_fmt_si_sub_minus (self, value, decimals, expected)
def | test_fmt_si_binary_sub_plus (self, value, decimals, expected)
def | test_fmt_si_binary_sub_minus (self, value, decimals, expected)
def | test_fmt_si_plus_fullrange (self, value, decimals, expected)
def | test_fmt_si_minus_fullrange (self, value, decimals, expected)
def | test_fmt_units_per_interval (self, units, seconds, unit, expected)
def | test_fmt_units_per_interval_negative_duration_exception (self, units, seconds, unit)

## Detailed Description

Definition at line 11 of file test_stringutil_formatters.py.

## Member Function Documentation

## ◆ test_fmt_si_bin_minus()

def tests.test_stringutil_formatters.TestStringUtilFormatters.test_fmt_si_bin_minus | ( |  | self,
|  |  | value,
|  |  | decimals,
|  |  | expected
| ) |  |

Definition at line 87 of file test_stringutil_formatters.py.

## ◆ test_fmt_si_bin_plus()

def tests.test_stringutil_formatters.TestStringUtilFormatters.test_fmt_si_bin_plus | ( |  | self,
|  |  | value,
|  |  | decimals,
|  |  | expected
| ) |  |

Definition at line 64 of file test_stringutil_formatters.py.

## ◆ test_fmt_si_bin_plus_no_decimals()

def tests.test_stringutil_formatters.TestStringUtilFormatters.test_fmt_si_bin_plus_no_decimals | ( |  | self,
|  |  | value,
|  |  | expected
| ) |  |

Definition at line 74 of file test_stringutil_formatters.py.

## ◆ test_fmt_si_binary_sub_minus()

def tests.test_stringutil_formatters.TestStringUtilFormatters.test_fmt_si_binary_sub_minus | ( |  | self,
|  |  | value,
|  |  | decimals,
|  |  | expected
| ) |  |

Definition at line 155 of file test_stringutil_formatters.py.

## ◆ test_fmt_si_binary_sub_plus()

def tests.test_stringutil_formatters.TestStringUtilFormatters.test_fmt_si_binary_sub_plus | ( |  | self,
|  |  | value,
|  |  | decimals,
|  |  | expected
| ) |  |

Definition at line 142 of file test_stringutil_formatters.py.

## ◆ test_fmt_si_minus()

def tests.test_stringutil_formatters.TestStringUtilFormatters.test_fmt_si_minus | ( |  | self,
|  |  | value,
|  |  | decimals,
|  |  | expected
| ) |  |

Definition at line 50 of file test_stringutil_formatters.py.

## ◆ test_fmt_si_minus_fullrange()

def tests.test_stringutil_formatters.TestStringUtilFormatters.test_fmt_si_minus_fullrange | ( |  | self,
|  |  | value,
|  |  | decimals,
|  |  | expected
| ) |  |

Definition at line 202 of file test_stringutil_formatters.py.

## ◆ test_fmt_si_plus()

def tests.test_stringutil_formatters.TestStringUtilFormatters.test_fmt_si_plus | ( |  | self,
|  |  | value,
|  |  | decimals,
|  |  | expected
| ) |  |

Definition at line 26 of file test_stringutil_formatters.py.

## ◆ test_fmt_si_plus_fullrange()

def tests.test_stringutil_formatters.TestStringUtilFormatters.test_fmt_si_plus_fullrange | ( |  | self,
|  |  | value,
|  |  | decimals,
|  |  | expected
| ) |  |

Definition at line 179 of file test_stringutil_formatters.py.

## ◆ test_fmt_si_plus_no_decimals()

def tests.test_stringutil_formatters.TestStringUtilFormatters.test_fmt_si_plus_no_decimals | ( |  | self,
|  |  | value,
|  |  | expected
| ) |  |

Definition at line 35 of file test_stringutil_formatters.py.

## ◆ test_fmt_si_sub_minus()

def tests.test_stringutil_formatters.TestStringUtilFormatters.test_fmt_si_sub_minus | ( |  | self,
|  |  | value,
|  |  | decimals,
|  |  | expected
| ) |  |

Definition at line 128 of file test_stringutil_formatters.py.

## ◆ test_fmt_si_sub_plus()

def tests.test_stringutil_formatters.TestStringUtilFormatters.test_fmt_si_sub_plus | ( |  | self,
|  |  | value,
|  |  | decimals,
|  |  | expected
| ) |  |

Definition at line 104 of file test_stringutil_formatters.py.

## ◆ test_fmt_si_sub_plus_no_decimals()

def tests.test_stringutil_formatters.TestStringUtilFormatters.test_fmt_si_sub_plus_no_decimals | ( |  | self,
|  |  | value,
|  |  | expected
| ) |  |

Definition at line 115 of file test_stringutil_formatters.py.

## ◆ test_fmt_units_per_interval()

def tests.test_stringutil_formatters.TestStringUtilFormatters.test_fmt_units_per_interval | ( |  | self,
|  |  | units,
|  |  | seconds,
|  |  | unit,
|  |  | expected
| ) |  |

Definition at line 225 of file test_stringutil_formatters.py.

## ◆ test_fmt_units_per_interval_negative_duration_exception()

def tests.test_stringutil_formatters.TestStringUtilFormatters.test_fmt_units_per_interval_negative_duration_exception | ( |  | self,
|  |  | units,
|  |  | seconds,
|  |  | unit
| ) |  |

Definition at line 231 of file test_stringutil_formatters.py.

The documentation for this class was generated from the following file:

- tests/test_stringutil_formatters.py